@@ -10,7 +10,7 @@ use Carp;
 BEGIN {
     use Exporter ();
     use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-    $VERSION     = '1.0003';
+    $VERSION     = '1.0004';
     @ISA         = qw(Exporter);
     @EXPORT      = qw();
     @EXPORT_OK   = qw();
@@ -352,6 +352,7 @@ sub cleanup {
     if ($self->{-selfrender}) {
         $self->{line} = '';
         $str = $self->_render ($self->{root}, '');
+        $str .= "\n" if $str !~ /\n$/s;
     } else {
         my @renderOptions = (undef, '   ', {});
 
@@ -371,6 +372,32 @@ sub cleanup {
     return $str;
 }
 
+
+=head2 elements
+
+C<elements> takes no parameters and returns the list of HTML::Element instances
+generated by C<cleanup>. C<elements> should only be called after C<cleanup>. It
+will return C<undef> if C<cleanup> was not called or failed.
+
+    $norm->cleanup ();
+    my @elements = $norm->elements();
+
+=cut
+
+sub elements {
+    my ($self) = @_;
+    my $root = $self->{root};
+
+    while ($root->implicit()) {
+        ($root) = grep {$_->tag() ne 'head'} $root->content_list();
+        last if $root->tag() eq 'body';
+        next;
+    }
+
+    return $root->content_list();
+}
+
+
 sub _cleanedupElt {
     my ($self, $parent) = @_;
 
@@ -595,6 +622,7 @@ sub _flushLine {
     }
 
     $self->{line} = '';
+    $str =~ s/\s+\n\z/\n/s;
     return $str;
 }
 
@@ -638,7 +666,7 @@ sub _renderText {
     } else {
         my $maxLen = $self->{-maxlinelen} - length $indent;
 
-        $str =~ s/(.{,$maxLen})\s+/$indent$1\n/g;
+        $str =~ s/(.{1,$maxLen})\s+/$indent$1\n/g if length($str) > $maxLen;
         ($str, $self->{line}) = $str =~ /(.*\n)?(.*)/;
         $str = '' unless defined $str;
         $self->{line} = '' unless defined $self->{line};
@@ -723,4 +751,3 @@ The full text of the license can be found in the
 LICENSE file included with this module.
 
 =cut
-
